package Perl::Tutorial;

use strict;
use warnings;

=head1 NAME

Perl::Tutorial - a tutorial for Perl.

=head1 SYNOPSIS

  perldoc Perl::Tutorial::HelloWorld

=head1 SEE ALSO

There are many good Perl tutorials available online - see L<http://perl-tutorial.org/> for a roundup.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 Copperly Ltd.

This module is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1;
